<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:template match="input | select | textarea">
        <xsl:copy>
            <xsl:apply-templates select="@*" />
            <xsl:attribute name="disabled">disabled</xsl:attribute>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    <xsl:template match="a">
        <xsl:copy>
            <xsl:choose>
                <!-- If it is a tab, then we will not try and disable it -->
                <xsl:when test="contains(@class, 'selectedTab') or contains(@class, 'unselectedTab')">
                    <xsl:apply-templates select="@*" />
                </xsl:when>
                <!-- If it is a collapsible section, then we will not try and disable it -->
                <xsl:when test="contains(@class, 'toggleHidden') or contains(@class, 'toggleVisible')">
                    <xsl:apply-templates select="@*" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="@*[(local-name() != 'href') and not(starts-with(local-name(), 'on'))]" />
                    <xsl:attribute name="disabled">disabled</xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    <!-- Ensure that we never disable controls or group contents that have the neverReadOnly class applied to them -->
	<!-- The class can be added to a Group, a Control Background if you don't want to disable all parts of the control e.g. Calendar or hidden xpath fields, or just the actual Field Control. --> 
    <xsl:template match="*[contains(@class, 'neverReadOnly')]" priority="10">
        <xsl:copy-of select=".">
        </xsl:copy-of>
    </xsl:template>
    <!-- This Template will ensure that the Save and Complete WIH buttons have no effect, by overriding the standard function processing with nothing if the Application is in ReadOnly mode -->  
    <xsl:template match="html/body">
        <xsl:copy>
            <xsl:apply-templates select="@*" />
            <xsl:apply-templates />
            <script>
            function onWorkitemComplete()
            {
            }
            function onWorkitemSave()
            {
            }
            </script>
        </xsl:copy>
    </xsl:template>
    <!-- Catchall to ensure all other content is copied across -->
    <xsl:template match="node() | @*">
        <xsl:copy>
            <xsl:apply-templates select="@*" />
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>
